<h1 align="center"> Tolio - Rust Extension </h1>

```
VERSION 0.2.2

Using: Rust 1.66.0 | Maturin 0.14.7
Supports: Python 3.10+
Source Code: src/rust/

```

### Description
This python package was build in rust, using maturin, to complement the <a href="https://github.com/jozhw/tolio">Tolio</a> application. The rationale behind using rust is to offer increased speed and performance when interacting
with the database.



### Limitations
This python package only supports database functionalities that are specific to the Tolio application. None of the functionalities 
that this package offers will be usable for any other purpose. 
